==> fet_6.7.6.orig.tar.bz2: fet-6.7.6/src/interface/constraintteacherafternoonsearlymaxbeginningsatsecondhourform.h <==
/***************************************************************************
                          constraintteacherafternoonsearlymaxbeginningsatsecondhourform.h  -  description
                             -------------------
    begin                : July 18, 2007
    copyright            : (C) 2007 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTTEACHERAFTERNOONSEARLYMAXBEGINNINGSATSECONDHOURFORM_H
#define CONSTRAINTTEACHERAFTERNOONSEARLYMAXBEGINNINGSATSECONDHOURFORM_H

#include "ui_constraintteacherafternoonsearlymaxbeginningsatsecondhourform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ConstraintTeacherAfternoonsEarlyMaxBeginningsAtSecondHourForm : public QDialog, Ui::ConstraintTeacherAfternoonsEarlyMaxBeginningsAtSecondHourForm_template  {
	Q_OBJECT
public:
	TimeConstraintsList visibleConstraintsList;

	ConstraintTeacherAfternoonsEarlyMaxBeginningsAtSecondHourForm(QWidget* parent);
	~ConstraintTeacherAfternoonsEarlyMaxBeginningsAtSecondHourForm();

	bool filterOk(TimeConstraint* ctr);

public slots:
	void constraintChanged(int index);
	void addConstraint();
	void modifyConstraint();
	void removeConstraint();

	void filterChanged();
};

#endif

==> fet_6.8.5.orig.tar.bz2: fet-6.8.5/src/interface/constraintteacherafternoonsearlymaxbeginningsatsecondhourform.h <==
/***************************************************************************
                          constraintteacherafternoonsearlymaxbeginningsatsecondhourform.h  -  description
                             -------------------
    begin                : July 18, 2007
    copyright            : (C) 2007 by Liviu Lalescu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTTEACHERAFTERNOONSEARLYMAXBEGINNINGSATSECONDHOURFORM_H
#define CONSTRAINTTEACHERAFTERNOONSEARLYMAXBEGINNINGSATSECONDHOURFORM_H

#include "ui_constraintteacherafternoonsearlymaxbeginningsatsecondhourform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ConstraintTeacherAfternoonsEarlyMaxBeginningsAtSecondHourForm : public QDialog, Ui::ConstraintTeacherAfternoonsEarlyMaxBeginningsAtSecondHourForm_template  {
	Q_OBJECT
public:
	TimeConstraintsList visibleConstraintsList;

	ConstraintTeacherAfternoonsEarlyMaxBeginningsAtSecondHourForm(QWidget* parent);
	~ConstraintTeacherAfternoonsEarlyMaxBeginningsAtSecondHourForm();

	bool filterOk(TimeConstraint* ctr);

public slots:
	void constraintChanged(int index);
	void addConstraint();
	void modifyConstraint();
	void removeConstraint();

	void filterChanged();
};

#endif
